# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inorbit.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='inorbit.proto',
  package='inorbit',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rinorbit.proto\x12\x07inorbit\"?\n\x10\x44iskUsageMessage\x12\x11\n\tvolume_id\x18\x01 \x01(\t\x12\x18\n\x10usage_percentage\x18\x02 \x01(\x02\"C\n\x13NetworkStatsMessage\x12\x14\n\x0cinterface_id\x18\x01 \x01(\t\x12\n\n\x02tx\x18\x02 \x01(\x03\x12\n\n\x02rx\x18\x03 \x01(\x03\"\xe6\x03\n\x12SystemStatsMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x17\n\x0f\x65lapsed_seconds\x18\x02 \x01(\x02\x12\x1b\n\x13\x63pu_load_percentage\x18\x03 \x01(\x02\x12\x19\n\x11network_interface\x18\x04 \x01(\t\x12\x10\n\x08total_tx\x18\x05 \x01(\x03\x12\x10\n\x08total_rx\x18\x06 \x01(\x03\x12\x12\n\ninorbit_tx\x18\x07 \x01(\x03\x12\x12\n\ninorbit_rx\x18\x08 \x01(\x03\x12\x1c\n\x14hdd_usage_percentage\x18\t \x01(\x02\x12\x1c\n\x14inorbit_hdd_usage_mb\x18\n \x01(\x02\x12$\n\x1cinorbit_hdd_usage_percentage\x18\x0b \x01(\x02\x12\x36\n\x13optional_disks_data\x18\x0f \x03(\x0b\x32\x19.inorbit.DiskUsageMessage\x12\x46\n optional_network_interfaces_data\x18\x10 \x03(\x0b\x32\x1c.inorbit.NetworkStatsMessage\x12\x1c\n\x14ram_usage_percentage\x18\x11 \x01(\x02\x12\x0f\n\x07mqtt_tx\x18\x12 \x01(\x03\x12\x0f\n\x07mqtt_rx\x18\x13 \x01(\x03\"\xac\x01\n\x13OdometryDataMessage\x12\x10\n\x08ts_start\x18\x01 \x01(\x03\x12\n\n\x02ts\x18\x02 \x01(\x03\x12\x17\n\x0flinear_distance\x18\x03 \x01(\x02\x12\x18\n\x10\x61ngular_distance\x18\x04 \x01(\x02\x12\x14\n\x0clinear_speed\x18\x05 \x01(\x02\x12\x15\n\rangular_speed\x18\x06 \x01(\x02\x12\x17\n\x0fspeed_available\x18\x07 \x01(\x08\"!\n\tPathPoint\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"n\n\x12\x44\x65ltaIntPathPoints\x12\"\n\x02xs\x18\x01 \x01(\x0b\x32\x16.inorbit.DeltaIntArray\x12\"\n\x02ys\x18\x02 \x01(\x0b\x32\x16.inorbit.DeltaIntArray\x12\x10\n\x08max_bits\x18\x03 \x01(\x05\"\xad\x01\n\tRobotPath\x12\"\n\x06points\x18\x01 \x03(\x0b\x32\x12.inorbit.PathPoint\x12\n\n\x02ts\x18\x02 \x01(\x03\x12\x0f\n\x07path_id\x18\x03 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x04 \x01(\t\x12\x18\n\x10\x65ncoding_version\x18\x05 \x01(\x05\x12\x33\n\x0e\x65ncoded_points\x18\x06 \x01(\x0b\x32\x1b.inorbit.DeltaIntPathPoints\"\xa1\x01\n\rDeltaIntArray\x12\x0e\n\x06\x61nchor\x18\x01 \x01(\x02\x12\x10\n\x08\x65xponent\x18\x02 \x01(\x11\x12\x0e\n\x06\x64\x65ltas\x18\x03 \x03(\x11\x12\x30\n\x05stats\x18\x04 \x03(\x0b\x32!.inorbit.DeltaIntArray.StatsEntry\x1a,\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"d\n\x0fPathDataMessage\x12\"\n\x06points\x18\x01 \x03(\x0b\x32\x12.inorbit.PathPoint\x12\n\n\x02ts\x18\x02 \x01(\x03\x12!\n\x05paths\x18\x03 \x03(\x0b\x32\x12.inorbit.RobotPath\"\xd7\x01\n\nMapMessage\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\x12\x0e\n\x06pixels\x18\x03 \x01(\x0c\x12\t\n\x01x\x18\x04 \x01(\x02\x12\t\n\x01y\x18\x05 \x01(\x02\x12\r\n\x05theta\x18\x06 \x01(\x02\x12\x12\n\nresolution\x18\x07 \x01(\x02\x12\n\n\x02ts\x18\x08 \x01(\x03\x12\r\n\x05label\x18\t \x01(\t\x12\x11\n\tdata_hash\x18\n \x01(\x03\x12\x10\n\x08\x66rame_id\x18\x0b \x01(\t\x12\x0e\n\x06map_id\x18\x0c \x01(\t\x12\x11\n\tis_update\x18\r \x01(\x08\".\n\nMapRequest\x12\r\n\x05label\x18\t \x01(\t\x12\x11\n\tdata_hash\x18\n \x01(\x03\"g\n\x14Nav2DWaypointMessage\x12*\n\x05\x66rame\x18\x01 \x01(\x0e\x32\x1b.inorbit.Nav2DWaypointFrame\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\r\n\x05theta\x18\x04 \x01(\x02\"\x81\x01\n\x10Nav2DPathMessage\x12*\n\x05\x66rame\x18\x01 \x01(\x0e\x32\x1b.inorbit.Nav2DWaypointFrame\x12\x0f\n\x07ts_hint\x18\x02 \x01(\x03\x12\x30\n\twaypoints\x18\x03 \x03(\x0b\x32\x1d.inorbit.Nav2DWaypointMessage\"n\n\x0c\x41lertMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x14\n\x0c\x63omponent_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"f\n\x04\x45\x63ho\x12\x12\n\ntime_stamp\x18\x01 \x01(\x03\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x18\n\x0estring_payload\x18\x03 \x01(\tH\x00\x12\x16\n\x0c\x62yte_payload\x18\x04 \x01(\x0cH\x00\x42\t\n\x07payload\"\x9f\x02\n\x14\x44\x61tabagUpdateMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0fstored_in_robot\x18\x02 \x01(\x08\x12\x1a\n\x12uploading_to_cloud\x18\x03 \x01(\x08\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x10\n\x08start_ts\x18\x05 \x01(\x03\x12\x0e\n\x06\x65nd_ts\x18\x06 \x01(\x03\x12\x0f\n\x07size_kb\x18\x07 \x01(\x05\x12\x0e\n\x06topics\x18\t \x03(\t\x12\x41\n\nproperties\x18\x08 \x03(\x0b\x32-.inorbit.DatabagUpdateMessage.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa9\x02\n\x13RosbagUpdateMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0fstored_in_robot\x18\x02 \x01(\x08\x12\x1a\n\x12uploading_to_cloud\x18\x03 \x01(\x08\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\n\n\x02ts\x18\x05 \x01(\x03\x12\x10\n\x08start_ts\x18\x06 \x01(\x03\x12\x0e\n\x06\x65nd_ts\x18\x07 \x01(\x03\x12\x0f\n\x07size_kb\x18\x08 \x01(\x05\x12\x0e\n\x06topics\x18\t \x03(\t\x12@\n\nproperties\x18\n \x03(\x0b\x32,.inorbit.RosbagUpdateMessage.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0cLaserMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x06ranges\x18\x02 \x01(\x0b\x32\x1a.inorbit.FloatingPointList\"1\n\x11\x46loatingPointList\x12\x0c\n\x04runs\x18\x01 \x03(\r\x12\x0e\n\x06values\x18\x02 \x03(\x02\"\x88\x01\n\x16LocationAndPoseMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\r\n\x05pos_x\x18\x02 \x01(\x02\x12\r\n\x05pos_y\x18\x03 \x01(\x02\x12\x0b\n\x03yaw\x18\x04 \x01(\x02\x12\x10\n\x08\x66rame_id\x18\x06 \x01(\t\x12%\n\x06lasers\x18\x05 \x03(\x0b\x32\x15.inorbit.LaserMessage\"6\n\x0bPoseMessage\x12\'\n\x05poses\x18\x01 \x03(\x0b\x32\x18.inorbit.PoseMessageData\"Z\n\x0fPoseMessageData\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\r\n\x05pos_x\x18\x02 \x01(\x02\x12\r\n\x05pos_y\x18\x03 \x01(\x02\x12\x0b\n\x03yaw\x18\x04 \x01(\x02\x12\x10\n\x08\x66rame_id\x18\x05 \x01(\t\"\\\n\rCameraMessage\x12\x11\n\tcamera_id\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\r\n\x05image\x18\x04 \x01(\x0c\x12\n\n\x02ts\x18\x05 \x01(\x03\"\x87\x01\n\rRobotFileData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0fstored_in_robot\x18\x02 \x01(\x08\x12\x1a\n\x12uploading_to_cloud\x18\x03 \x01(\x08\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\n\n\x02ts\x18\x05 \x01(\x03\x12\x0c\n\x04size\x18\x06 \x01(\x03\x12\x0c\n\x04type\x18\x07 \x01(\t\"P\n\x17RobotFilesUpdateMessage\x12)\n\tartifacts\x18\x01 \x03(\x0b\x32\x16.inorbit.RobotFileData\x12\n\n\x02ts\x18\x02 \x01(\x03\"?\n\x15KeyValueCustomElement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\n\n\x02ts\x18\x03 \x01(\x03\">\n\rKeyValuePairs\x12-\n\x05pairs\x18\x01 \x03(\x0b\x32\x1e.inorbit.KeyValueCustomElement\"?\n\x12\x44iagnosticsMessage\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"`\n\x0fTextFileMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x13\n\x0b\x62lob_offset\x18\x02 \x01(\x05\x12\x11\n\tblob_size\x18\x03 \x01(\x05\x12\x17\n\x0ftotal_file_size\x18\x04 \x01(\x05\"\xa0\x02\n\x11\x43ustomDataMessage\x12\x14\n\x0c\x63ustom_field\x18\x01 \x01(\t\x12\x33\n\x11key_value_payload\x18\x02 \x01(\x0b\x32\x16.inorbit.KeyValuePairsH\x00\x12\x17\n\rimage_payload\x18\x03 \x01(\x0cH\x00\x12\x1b\n\x11text_file_payload\x18\x04 \x01(\x0cH\x00\x12:\n\x13\x64iagnostics_payload\x18\x05 \x01(\x0b\x32\x1b.inorbit.DiagnosticsMessageH\x00\x12\x37\n\x13text_file_payload_2\x18\x06 \x01(\x0b\x32\x18.inorbit.TextFileMessageH\x00\x12\n\n\x02ts\x18\x07 \x01(\x03\x42\t\n\x07payload\"C\n\x13TopicMonitorMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08has_rate\x18\x02 \x01(\x08\x12\x0c\n\x04rate\x18\x03 \x01(\x05\"2\n\x13ParamMonitorMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"M\n\x12NodeMonitorMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11has_ping_response\x18\x02 \x01(\x08\x12\x0e\n\x06pinged\x18\x03 \x01(\x08\"%\n\x15ServiceMonitorMessage\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x8c\x02\n\x11RosMonitorMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x15\n\rmaster_status\x18\x02 \x01(\x05\x12\x33\n\rtopics_update\x18\x03 \x03(\x0b\x32\x1c.inorbit.TopicMonitorMessage\x12\x33\n\rparams_update\x18\x04 \x03(\x0b\x32\x1c.inorbit.ParamMonitorMessage\x12\x31\n\x0cnodes_update\x18\x05 \x03(\x0b\x32\x1b.inorbit.NodeMonitorMessage\x12\x37\n\x0fservices_update\x18\x06 \x03(\x0b\x32\x1e.inorbit.ServiceMonitorMessage\"B\n\rRosOutMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x0b\n\x03log\x18\x02 \x01(\x0c\x12\x18\n\x10has_skipped_msgs\x18\x03 \x01(\x08\"2\n\x17\x43ustomCommandRosMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x0b\n\x03\x63md\x18\x02 \x01(\t\"\x8c\x01\n\x1a\x43ustomScriptCommandMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x13\n\x0b\x61rg_options\x18\x03 \x03(\t\x12\x17\n\x0fscript_contents\x18\x04 \x01(\t\x12\x0b\n\x03run\x18\x05 \x01(\x08\x12\x14\n\x0c\x65xecution_id\x18\x06 \x01(\t\"\xc1\x01\n\x19\x43ustomScriptStatusMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x18\n\x10\x65xecution_status\x18\x03 \x01(\t\x12\x13\n\x0breturn_code\x18\x04 \x01(\t\x12\x0e\n\x06stdout\x18\x05 \x01(\t\x12\x0e\n\x06stderr\x18\x06 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x07 \x01(\t\x12 \n\x18\x65xecution_status_details\x18\x08 \x01(\t\"U\n\x0fTeleopGoCommand\x12\x0f\n\x07ts_hint\x18\x01 \x01(\x03\x12\x17\n\x0flinear_velocity\x18\x02 \x01(\x02\x12\x18\n\x10\x61ngular_velocity\x18\x03 \x01(\x02\"-\n\x0fKeyValueMessage\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x80\x01\n\x13RosDiagnosticsField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x05\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12,\n\nkey_values\x18\x04 \x03(\x0b\x32\x18.inorbit.KeyValueMessage\x12\x11\n\thas_level\x18\x05 \x01(\x08\"Q\n\x15RosDiagnosticsMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12,\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x1c.inorbit.RosDiagnosticsField\"M\n\x1bRosDiagnosticsStatusMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x12\n\nhas_status\x18\x03 \x01(\x08\"2\n\x0cStateOptions\x12\x12\n\nstate_name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"^\n\x19ModuleStateOptionsMessage\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\x12,\n\rstate_options\x18\x02 \x03(\x0b\x32\x15.inorbit.StateOptions*5\n\x12Nav2DWaypointFrame\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MAP\x10\x01\x12\t\n\x05ROBOT\x10\x02\x62\x06proto3'
)

_NAV2DWAYPOINTFRAME = _descriptor.EnumDescriptor(
  name='Nav2DWaypointFrame',
  full_name='inorbit.Nav2DWaypointFrame',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROBOT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5575,
  serialized_end=5628,
)
_sym_db.RegisterEnumDescriptor(_NAV2DWAYPOINTFRAME)

Nav2DWaypointFrame = enum_type_wrapper.EnumTypeWrapper(_NAV2DWAYPOINTFRAME)
UNKNOWN = 0
MAP = 1
ROBOT = 2



_DISKUSAGEMESSAGE = _descriptor.Descriptor(
  name='DiskUsageMessage',
  full_name='inorbit.DiskUsageMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volume_id', full_name='inorbit.DiskUsageMessage.volume_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage_percentage', full_name='inorbit.DiskUsageMessage.usage_percentage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=89,
)


_NETWORKSTATSMESSAGE = _descriptor.Descriptor(
  name='NetworkStatsMessage',
  full_name='inorbit.NetworkStatsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='inorbit.NetworkStatsMessage.interface_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx', full_name='inorbit.NetworkStatsMessage.tx', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx', full_name='inorbit.NetworkStatsMessage.rx', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=158,
)


_SYSTEMSTATSMESSAGE = _descriptor.Descriptor(
  name='SystemStatsMessage',
  full_name='inorbit.SystemStatsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='inorbit.SystemStatsMessage.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elapsed_seconds', full_name='inorbit.SystemStatsMessage.elapsed_seconds', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_load_percentage', full_name='inorbit.SystemStatsMessage.cpu_load_percentage', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface', full_name='inorbit.SystemStatsMessage.network_interface', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_tx', full_name='inorbit.SystemStatsMessage.total_tx', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_rx', full_name='inorbit.SystemStatsMessage.total_rx', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inorbit_tx', full_name='inorbit.SystemStatsMessage.inorbit_tx', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inorbit_rx', full_name='inorbit.SystemStatsMessage.inorbit_rx', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hdd_usage_percentage', full_name='inorbit.SystemStatsMessage.hdd_usage_percentage', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inorbit_hdd_usage_mb', full_name='inorbit.SystemStatsMessage.inorbit_hdd_usage_mb', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inorbit_hdd_usage_percentage', full_name='inorbit.SystemStatsMessage.inorbit_hdd_usage_percentage', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_disks_data', full_name='inorbit.SystemStatsMessage.optional_disks_data', index=11,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional_network_interfaces_data', full_name='inorbit.SystemStatsMessage.optional_network_interfaces_data', index=12,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ram_usage_percentage', full_name='inorbit.SystemStatsMessage.ram_usage_percentage', index=13,
      number=17, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mqtt_tx', full_name='inorbit.SystemStatsMessage.mqtt_tx', index=14,
      number=18, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mqtt_rx', full_name='inorbit.SystemStatsMessage.mqtt_rx', index=15,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=647,
)


_ODOMETRYDATAMESSAGE = _descriptor.Descriptor(
  name='OdometryDataMessage',
  full_name='inorbit.OdometryDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts_start', full_name='inorbit.OdometryDataMessage.ts_start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.OdometryDataMessage.ts', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_distance', full_name='inorbit.OdometryDataMessage.linear_distance', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_distance', full_name='inorbit.OdometryDataMessage.angular_distance', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_speed', full_name='inorbit.OdometryDataMessage.linear_speed', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_speed', full_name='inorbit.OdometryDataMessage.angular_speed', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_available', full_name='inorbit.OdometryDataMessage.speed_available', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=822,
)


_PATHPOINT = _descriptor.Descriptor(
  name='PathPoint',
  full_name='inorbit.PathPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='inorbit.PathPoint.x', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='inorbit.PathPoint.y', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=824,
  serialized_end=857,
)


_DELTAINTPATHPOINTS = _descriptor.Descriptor(
  name='DeltaIntPathPoints',
  full_name='inorbit.DeltaIntPathPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='xs', full_name='inorbit.DeltaIntPathPoints.xs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ys', full_name='inorbit.DeltaIntPathPoints.ys', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_bits', full_name='inorbit.DeltaIntPathPoints.max_bits', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=969,
)


_ROBOTPATH = _descriptor.Descriptor(
  name='RobotPath',
  full_name='inorbit.RobotPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='inorbit.RobotPath.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RobotPath.ts', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_id', full_name='inorbit.RobotPath.path_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='inorbit.RobotPath.frame_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoding_version', full_name='inorbit.RobotPath.encoding_version', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoded_points', full_name='inorbit.RobotPath.encoded_points', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1145,
)


_DELTAINTARRAY_STATSENTRY = _descriptor.Descriptor(
  name='StatsEntry',
  full_name='inorbit.DeltaIntArray.StatsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='inorbit.DeltaIntArray.StatsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='inorbit.DeltaIntArray.StatsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1265,
  serialized_end=1309,
)

_DELTAINTARRAY = _descriptor.Descriptor(
  name='DeltaIntArray',
  full_name='inorbit.DeltaIntArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='anchor', full_name='inorbit.DeltaIntArray.anchor', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exponent', full_name='inorbit.DeltaIntArray.exponent', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deltas', full_name='inorbit.DeltaIntArray.deltas', index=2,
      number=3, type=17, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats', full_name='inorbit.DeltaIntArray.stats', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DELTAINTARRAY_STATSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1309,
)


_PATHDATAMESSAGE = _descriptor.Descriptor(
  name='PathDataMessage',
  full_name='inorbit.PathDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='points', full_name='inorbit.PathDataMessage.points', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.PathDataMessage.ts', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paths', full_name='inorbit.PathDataMessage.paths', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1311,
  serialized_end=1411,
)


_MAPMESSAGE = _descriptor.Descriptor(
  name='MapMessage',
  full_name='inorbit.MapMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='inorbit.MapMessage.width', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='inorbit.MapMessage.height', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pixels', full_name='inorbit.MapMessage.pixels', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='inorbit.MapMessage.x', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='inorbit.MapMessage.y', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='inorbit.MapMessage.theta', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='inorbit.MapMessage.resolution', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.MapMessage.ts', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='inorbit.MapMessage.label', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='inorbit.MapMessage.data_hash', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='inorbit.MapMessage.frame_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_id', full_name='inorbit.MapMessage.map_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_update', full_name='inorbit.MapMessage.is_update', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1414,
  serialized_end=1629,
)


_MAPREQUEST = _descriptor.Descriptor(
  name='MapRequest',
  full_name='inorbit.MapRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='inorbit.MapRequest.label', index=0,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='inorbit.MapRequest.data_hash', index=1,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1677,
)


_NAV2DWAYPOINTMESSAGE = _descriptor.Descriptor(
  name='Nav2DWaypointMessage',
  full_name='inorbit.Nav2DWaypointMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame', full_name='inorbit.Nav2DWaypointMessage.frame', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x', full_name='inorbit.Nav2DWaypointMessage.x', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='inorbit.Nav2DWaypointMessage.y', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='inorbit.Nav2DWaypointMessage.theta', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1679,
  serialized_end=1782,
)


_NAV2DPATHMESSAGE = _descriptor.Descriptor(
  name='Nav2DPathMessage',
  full_name='inorbit.Nav2DPathMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame', full_name='inorbit.Nav2DPathMessage.frame', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts_hint', full_name='inorbit.Nav2DPathMessage.ts_hint', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='waypoints', full_name='inorbit.Nav2DPathMessage.waypoints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1785,
  serialized_end=1914,
)


_ALERTMESSAGE = _descriptor.Descriptor(
  name='AlertMessage',
  full_name='inorbit.AlertMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.AlertMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='component_id', full_name='inorbit.AlertMessage.component_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='inorbit.AlertMessage.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='inorbit.AlertMessage.level', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.AlertMessage.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='inorbit.AlertMessage.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=2026,
)


_ECHO = _descriptor.Descriptor(
  name='Echo',
  full_name='inorbit.Echo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='inorbit.Echo.time_stamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topic', full_name='inorbit.Echo.topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_payload', full_name='inorbit.Echo.string_payload', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='byte_payload', full_name='inorbit.Echo.byte_payload', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='inorbit.Echo.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2028,
  serialized_end=2130,
)


_DATABAGUPDATEMESSAGE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='inorbit.DatabagUpdateMessage.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='inorbit.DatabagUpdateMessage.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='inorbit.DatabagUpdateMessage.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2371,
  serialized_end=2420,
)

_DATABAGUPDATEMESSAGE = _descriptor.Descriptor(
  name='DatabagUpdateMessage',
  full_name='inorbit.DatabagUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.DatabagUpdateMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_in_robot', full_name='inorbit.DatabagUpdateMessage.stored_in_robot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uploading_to_cloud', full_name='inorbit.DatabagUpdateMessage.uploading_to_cloud', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='inorbit.DatabagUpdateMessage.url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_ts', full_name='inorbit.DatabagUpdateMessage.start_ts', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_ts', full_name='inorbit.DatabagUpdateMessage.end_ts', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_kb', full_name='inorbit.DatabagUpdateMessage.size_kb', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='inorbit.DatabagUpdateMessage.topics', index=7,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='inorbit.DatabagUpdateMessage.properties', index=8,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATABAGUPDATEMESSAGE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2133,
  serialized_end=2420,
)


_ROSBAGUPDATEMESSAGE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='inorbit.RosbagUpdateMessage.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='inorbit.RosbagUpdateMessage.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='inorbit.RosbagUpdateMessage.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2371,
  serialized_end=2420,
)

_ROSBAGUPDATEMESSAGE = _descriptor.Descriptor(
  name='RosbagUpdateMessage',
  full_name='inorbit.RosbagUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.RosbagUpdateMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_in_robot', full_name='inorbit.RosbagUpdateMessage.stored_in_robot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uploading_to_cloud', full_name='inorbit.RosbagUpdateMessage.uploading_to_cloud', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='inorbit.RosbagUpdateMessage.url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RosbagUpdateMessage.ts', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_ts', full_name='inorbit.RosbagUpdateMessage.start_ts', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_ts', full_name='inorbit.RosbagUpdateMessage.end_ts', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_kb', full_name='inorbit.RosbagUpdateMessage.size_kb', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='inorbit.RosbagUpdateMessage.topics', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='inorbit.RosbagUpdateMessage.properties', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ROSBAGUPDATEMESSAGE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2423,
  serialized_end=2720,
)


_LASERMESSAGE = _descriptor.Descriptor(
  name='LaserMessage',
  full_name='inorbit.LaserMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.LaserMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ranges', full_name='inorbit.LaserMessage.ranges', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2722,
  serialized_end=2794,
)


_FLOATINGPOINTLIST = _descriptor.Descriptor(
  name='FloatingPointList',
  full_name='inorbit.FloatingPointList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='runs', full_name='inorbit.FloatingPointList.runs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='inorbit.FloatingPointList.values', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2796,
  serialized_end=2845,
)


_LOCATIONANDPOSEMESSAGE = _descriptor.Descriptor(
  name='LocationAndPoseMessage',
  full_name='inorbit.LocationAndPoseMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.LocationAndPoseMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_x', full_name='inorbit.LocationAndPoseMessage.pos_x', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_y', full_name='inorbit.LocationAndPoseMessage.pos_y', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw', full_name='inorbit.LocationAndPoseMessage.yaw', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='inorbit.LocationAndPoseMessage.frame_id', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lasers', full_name='inorbit.LocationAndPoseMessage.lasers', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2848,
  serialized_end=2984,
)


_POSEMESSAGE = _descriptor.Descriptor(
  name='PoseMessage',
  full_name='inorbit.PoseMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poses', full_name='inorbit.PoseMessage.poses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2986,
  serialized_end=3040,
)


_POSEMESSAGEDATA = _descriptor.Descriptor(
  name='PoseMessageData',
  full_name='inorbit.PoseMessageData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.PoseMessageData.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_x', full_name='inorbit.PoseMessageData.pos_x', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_y', full_name='inorbit.PoseMessageData.pos_y', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw', full_name='inorbit.PoseMessageData.yaw', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='inorbit.PoseMessageData.frame_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3042,
  serialized_end=3132,
)


_CAMERAMESSAGE = _descriptor.Descriptor(
  name='CameraMessage',
  full_name='inorbit.CameraMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='camera_id', full_name='inorbit.CameraMessage.camera_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='inorbit.CameraMessage.width', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='inorbit.CameraMessage.height', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='inorbit.CameraMessage.image', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.CameraMessage.ts', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3134,
  serialized_end=3226,
)


_ROBOTFILEDATA = _descriptor.Descriptor(
  name='RobotFileData',
  full_name='inorbit.RobotFileData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.RobotFileData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_in_robot', full_name='inorbit.RobotFileData.stored_in_robot', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uploading_to_cloud', full_name='inorbit.RobotFileData.uploading_to_cloud', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='inorbit.RobotFileData.url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RobotFileData.ts', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='inorbit.RobotFileData.size', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='inorbit.RobotFileData.type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3229,
  serialized_end=3364,
)


_ROBOTFILESUPDATEMESSAGE = _descriptor.Descriptor(
  name='RobotFilesUpdateMessage',
  full_name='inorbit.RobotFilesUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='artifacts', full_name='inorbit.RobotFilesUpdateMessage.artifacts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RobotFilesUpdateMessage.ts', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3366,
  serialized_end=3446,
)


_KEYVALUECUSTOMELEMENT = _descriptor.Descriptor(
  name='KeyValueCustomElement',
  full_name='inorbit.KeyValueCustomElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='inorbit.KeyValueCustomElement.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='inorbit.KeyValueCustomElement.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.KeyValueCustomElement.ts', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3448,
  serialized_end=3511,
)


_KEYVALUEPAIRS = _descriptor.Descriptor(
  name='KeyValuePairs',
  full_name='inorbit.KeyValuePairs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pairs', full_name='inorbit.KeyValuePairs.pairs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3513,
  serialized_end=3575,
)


_DIAGNOSTICSMESSAGE = _descriptor.Descriptor(
  name='DiagnosticsMessage',
  full_name='inorbit.DiagnosticsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='inorbit.DiagnosticsMessage.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='inorbit.DiagnosticsMessage.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='inorbit.DiagnosticsMessage.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3577,
  serialized_end=3640,
)


_TEXTFILEMESSAGE = _descriptor.Descriptor(
  name='TextFileMessage',
  full_name='inorbit.TextFileMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='inorbit.TextFileMessage.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blob_offset', full_name='inorbit.TextFileMessage.blob_offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blob_size', full_name='inorbit.TextFileMessage.blob_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_file_size', full_name='inorbit.TextFileMessage.total_file_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3642,
  serialized_end=3738,
)


_CUSTOMDATAMESSAGE = _descriptor.Descriptor(
  name='CustomDataMessage',
  full_name='inorbit.CustomDataMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='custom_field', full_name='inorbit.CustomDataMessage.custom_field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_value_payload', full_name='inorbit.CustomDataMessage.key_value_payload', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_payload', full_name='inorbit.CustomDataMessage.image_payload', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_file_payload', full_name='inorbit.CustomDataMessage.text_file_payload', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diagnostics_payload', full_name='inorbit.CustomDataMessage.diagnostics_payload', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_file_payload_2', full_name='inorbit.CustomDataMessage.text_file_payload_2', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.CustomDataMessage.ts', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='inorbit.CustomDataMessage.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3741,
  serialized_end=4029,
)


_TOPICMONITORMESSAGE = _descriptor.Descriptor(
  name='TopicMonitorMessage',
  full_name='inorbit.TopicMonitorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.TopicMonitorMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_rate', full_name='inorbit.TopicMonitorMessage.has_rate', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rate', full_name='inorbit.TopicMonitorMessage.rate', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4031,
  serialized_end=4098,
)


_PARAMMONITORMESSAGE = _descriptor.Descriptor(
  name='ParamMonitorMessage',
  full_name='inorbit.ParamMonitorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.ParamMonitorMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='inorbit.ParamMonitorMessage.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4100,
  serialized_end=4150,
)


_NODEMONITORMESSAGE = _descriptor.Descriptor(
  name='NodeMonitorMessage',
  full_name='inorbit.NodeMonitorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.NodeMonitorMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_ping_response', full_name='inorbit.NodeMonitorMessage.has_ping_response', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pinged', full_name='inorbit.NodeMonitorMessage.pinged', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4152,
  serialized_end=4229,
)


_SERVICEMONITORMESSAGE = _descriptor.Descriptor(
  name='ServiceMonitorMessage',
  full_name='inorbit.ServiceMonitorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.ServiceMonitorMessage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4231,
  serialized_end=4268,
)


_ROSMONITORMESSAGE = _descriptor.Descriptor(
  name='RosMonitorMessage',
  full_name='inorbit.RosMonitorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RosMonitorMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='master_status', full_name='inorbit.RosMonitorMessage.master_status', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics_update', full_name='inorbit.RosMonitorMessage.topics_update', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params_update', full_name='inorbit.RosMonitorMessage.params_update', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodes_update', full_name='inorbit.RosMonitorMessage.nodes_update', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='services_update', full_name='inorbit.RosMonitorMessage.services_update', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4271,
  serialized_end=4539,
)


_ROSOUTMESSAGE = _descriptor.Descriptor(
  name='RosOutMessage',
  full_name='inorbit.RosOutMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RosOutMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='inorbit.RosOutMessage.log', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_skipped_msgs', full_name='inorbit.RosOutMessage.has_skipped_msgs', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4541,
  serialized_end=4607,
)


_CUSTOMCOMMANDROSMESSAGE = _descriptor.Descriptor(
  name='CustomCommandRosMessage',
  full_name='inorbit.CustomCommandRosMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.CustomCommandRosMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='inorbit.CustomCommandRosMessage.cmd', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4609,
  serialized_end=4659,
)


_CUSTOMSCRIPTCOMMANDMESSAGE = _descriptor.Descriptor(
  name='CustomScriptCommandMessage',
  full_name='inorbit.CustomScriptCommandMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.CustomScriptCommandMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='inorbit.CustomScriptCommandMessage.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arg_options', full_name='inorbit.CustomScriptCommandMessage.arg_options', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script_contents', full_name='inorbit.CustomScriptCommandMessage.script_contents', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run', full_name='inorbit.CustomScriptCommandMessage.run', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='inorbit.CustomScriptCommandMessage.execution_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4662,
  serialized_end=4802,
)


_CUSTOMSCRIPTSTATUSMESSAGE = _descriptor.Descriptor(
  name='CustomScriptStatusMessage',
  full_name='inorbit.CustomScriptStatusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.CustomScriptStatusMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='inorbit.CustomScriptStatusMessage.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_status', full_name='inorbit.CustomScriptStatusMessage.execution_status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_code', full_name='inorbit.CustomScriptStatusMessage.return_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdout', full_name='inorbit.CustomScriptStatusMessage.stdout', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stderr', full_name='inorbit.CustomScriptStatusMessage.stderr', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='inorbit.CustomScriptStatusMessage.execution_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_status_details', full_name='inorbit.CustomScriptStatusMessage.execution_status_details', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4805,
  serialized_end=4998,
)


_TELEOPGOCOMMAND = _descriptor.Descriptor(
  name='TeleopGoCommand',
  full_name='inorbit.TeleopGoCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts_hint', full_name='inorbit.TeleopGoCommand.ts_hint', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='inorbit.TeleopGoCommand.linear_velocity', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='inorbit.TeleopGoCommand.angular_velocity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5000,
  serialized_end=5085,
)


_KEYVALUEMESSAGE = _descriptor.Descriptor(
  name='KeyValueMessage',
  full_name='inorbit.KeyValueMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='inorbit.KeyValueMessage.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='inorbit.KeyValueMessage.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5087,
  serialized_end=5132,
)


_ROSDIAGNOSTICSFIELD = _descriptor.Descriptor(
  name='RosDiagnosticsField',
  full_name='inorbit.RosDiagnosticsField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='inorbit.RosDiagnosticsField.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='inorbit.RosDiagnosticsField.level', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='inorbit.RosDiagnosticsField.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_values', full_name='inorbit.RosDiagnosticsField.key_values', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_level', full_name='inorbit.RosDiagnosticsField.has_level', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5135,
  serialized_end=5263,
)


_ROSDIAGNOSTICSMESSAGE = _descriptor.Descriptor(
  name='RosDiagnosticsMessage',
  full_name='inorbit.RosDiagnosticsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RosDiagnosticsMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='inorbit.RosDiagnosticsMessage.fields', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5265,
  serialized_end=5346,
)


_ROSDIAGNOSTICSSTATUSMESSAGE = _descriptor.Descriptor(
  name='RosDiagnosticsStatusMessage',
  full_name='inorbit.RosDiagnosticsStatusMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ts', full_name='inorbit.RosDiagnosticsStatusMessage.ts', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='inorbit.RosDiagnosticsStatusMessage.status', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_status', full_name='inorbit.RosDiagnosticsStatusMessage.has_status', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5348,
  serialized_end=5425,
)


_STATEOPTIONS = _descriptor.Descriptor(
  name='StateOptions',
  full_name='inorbit.StateOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_name', full_name='inorbit.StateOptions.state_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='inorbit.StateOptions.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5427,
  serialized_end=5477,
)


_MODULESTATEOPTIONSMESSAGE = _descriptor.Descriptor(
  name='ModuleStateOptionsMessage',
  full_name='inorbit.ModuleStateOptionsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_name', full_name='inorbit.ModuleStateOptionsMessage.module_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_options', full_name='inorbit.ModuleStateOptionsMessage.state_options', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5479,
  serialized_end=5573,
)

_SYSTEMSTATSMESSAGE.fields_by_name['optional_disks_data'].message_type = _DISKUSAGEMESSAGE
_SYSTEMSTATSMESSAGE.fields_by_name['optional_network_interfaces_data'].message_type = _NETWORKSTATSMESSAGE
_DELTAINTPATHPOINTS.fields_by_name['xs'].message_type = _DELTAINTARRAY
_DELTAINTPATHPOINTS.fields_by_name['ys'].message_type = _DELTAINTARRAY
_ROBOTPATH.fields_by_name['points'].message_type = _PATHPOINT
_ROBOTPATH.fields_by_name['encoded_points'].message_type = _DELTAINTPATHPOINTS
_DELTAINTARRAY_STATSENTRY.containing_type = _DELTAINTARRAY
_DELTAINTARRAY.fields_by_name['stats'].message_type = _DELTAINTARRAY_STATSENTRY
_PATHDATAMESSAGE.fields_by_name['points'].message_type = _PATHPOINT
_PATHDATAMESSAGE.fields_by_name['paths'].message_type = _ROBOTPATH
_NAV2DWAYPOINTMESSAGE.fields_by_name['frame'].enum_type = _NAV2DWAYPOINTFRAME
_NAV2DPATHMESSAGE.fields_by_name['frame'].enum_type = _NAV2DWAYPOINTFRAME
_NAV2DPATHMESSAGE.fields_by_name['waypoints'].message_type = _NAV2DWAYPOINTMESSAGE
_ECHO.oneofs_by_name['payload'].fields.append(
  _ECHO.fields_by_name['string_payload'])
_ECHO.fields_by_name['string_payload'].containing_oneof = _ECHO.oneofs_by_name['payload']
_ECHO.oneofs_by_name['payload'].fields.append(
  _ECHO.fields_by_name['byte_payload'])
_ECHO.fields_by_name['byte_payload'].containing_oneof = _ECHO.oneofs_by_name['payload']
_DATABAGUPDATEMESSAGE_PROPERTIESENTRY.containing_type = _DATABAGUPDATEMESSAGE
_DATABAGUPDATEMESSAGE.fields_by_name['properties'].message_type = _DATABAGUPDATEMESSAGE_PROPERTIESENTRY
_ROSBAGUPDATEMESSAGE_PROPERTIESENTRY.containing_type = _ROSBAGUPDATEMESSAGE
_ROSBAGUPDATEMESSAGE.fields_by_name['properties'].message_type = _ROSBAGUPDATEMESSAGE_PROPERTIESENTRY
_LASERMESSAGE.fields_by_name['ranges'].message_type = _FLOATINGPOINTLIST
_LOCATIONANDPOSEMESSAGE.fields_by_name['lasers'].message_type = _LASERMESSAGE
_POSEMESSAGE.fields_by_name['poses'].message_type = _POSEMESSAGEDATA
_ROBOTFILESUPDATEMESSAGE.fields_by_name['artifacts'].message_type = _ROBOTFILEDATA
_KEYVALUEPAIRS.fields_by_name['pairs'].message_type = _KEYVALUECUSTOMELEMENT
_CUSTOMDATAMESSAGE.fields_by_name['key_value_payload'].message_type = _KEYVALUEPAIRS
_CUSTOMDATAMESSAGE.fields_by_name['diagnostics_payload'].message_type = _DIAGNOSTICSMESSAGE
_CUSTOMDATAMESSAGE.fields_by_name['text_file_payload_2'].message_type = _TEXTFILEMESSAGE
_CUSTOMDATAMESSAGE.oneofs_by_name['payload'].fields.append(
  _CUSTOMDATAMESSAGE.fields_by_name['key_value_payload'])
_CUSTOMDATAMESSAGE.fields_by_name['key_value_payload'].containing_oneof = _CUSTOMDATAMESSAGE.oneofs_by_name['payload']
_CUSTOMDATAMESSAGE.oneofs_by_name['payload'].fields.append(
  _CUSTOMDATAMESSAGE.fields_by_name['image_payload'])
_CUSTOMDATAMESSAGE.fields_by_name['image_payload'].containing_oneof = _CUSTOMDATAMESSAGE.oneofs_by_name['payload']
_CUSTOMDATAMESSAGE.oneofs_by_name['payload'].fields.append(
  _CUSTOMDATAMESSAGE.fields_by_name['text_file_payload'])
_CUSTOMDATAMESSAGE.fields_by_name['text_file_payload'].containing_oneof = _CUSTOMDATAMESSAGE.oneofs_by_name['payload']
_CUSTOMDATAMESSAGE.oneofs_by_name['payload'].fields.append(
  _CUSTOMDATAMESSAGE.fields_by_name['diagnostics_payload'])
_CUSTOMDATAMESSAGE.fields_by_name['diagnostics_payload'].containing_oneof = _CUSTOMDATAMESSAGE.oneofs_by_name['payload']
_CUSTOMDATAMESSAGE.oneofs_by_name['payload'].fields.append(
  _CUSTOMDATAMESSAGE.fields_by_name['text_file_payload_2'])
_CUSTOMDATAMESSAGE.fields_by_name['text_file_payload_2'].containing_oneof = _CUSTOMDATAMESSAGE.oneofs_by_name['payload']
_ROSMONITORMESSAGE.fields_by_name['topics_update'].message_type = _TOPICMONITORMESSAGE
_ROSMONITORMESSAGE.fields_by_name['params_update'].message_type = _PARAMMONITORMESSAGE
_ROSMONITORMESSAGE.fields_by_name['nodes_update'].message_type = _NODEMONITORMESSAGE
_ROSMONITORMESSAGE.fields_by_name['services_update'].message_type = _SERVICEMONITORMESSAGE
_ROSDIAGNOSTICSFIELD.fields_by_name['key_values'].message_type = _KEYVALUEMESSAGE
_ROSDIAGNOSTICSMESSAGE.fields_by_name['fields'].message_type = _ROSDIAGNOSTICSFIELD
_MODULESTATEOPTIONSMESSAGE.fields_by_name['state_options'].message_type = _STATEOPTIONS
DESCRIPTOR.message_types_by_name['DiskUsageMessage'] = _DISKUSAGEMESSAGE
DESCRIPTOR.message_types_by_name['NetworkStatsMessage'] = _NETWORKSTATSMESSAGE
DESCRIPTOR.message_types_by_name['SystemStatsMessage'] = _SYSTEMSTATSMESSAGE
DESCRIPTOR.message_types_by_name['OdometryDataMessage'] = _ODOMETRYDATAMESSAGE
DESCRIPTOR.message_types_by_name['PathPoint'] = _PATHPOINT
DESCRIPTOR.message_types_by_name['DeltaIntPathPoints'] = _DELTAINTPATHPOINTS
DESCRIPTOR.message_types_by_name['RobotPath'] = _ROBOTPATH
DESCRIPTOR.message_types_by_name['DeltaIntArray'] = _DELTAINTARRAY
DESCRIPTOR.message_types_by_name['PathDataMessage'] = _PATHDATAMESSAGE
DESCRIPTOR.message_types_by_name['MapMessage'] = _MAPMESSAGE
DESCRIPTOR.message_types_by_name['MapRequest'] = _MAPREQUEST
DESCRIPTOR.message_types_by_name['Nav2DWaypointMessage'] = _NAV2DWAYPOINTMESSAGE
DESCRIPTOR.message_types_by_name['Nav2DPathMessage'] = _NAV2DPATHMESSAGE
DESCRIPTOR.message_types_by_name['AlertMessage'] = _ALERTMESSAGE
DESCRIPTOR.message_types_by_name['Echo'] = _ECHO
DESCRIPTOR.message_types_by_name['DatabagUpdateMessage'] = _DATABAGUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['RosbagUpdateMessage'] = _ROSBAGUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['LaserMessage'] = _LASERMESSAGE
DESCRIPTOR.message_types_by_name['FloatingPointList'] = _FLOATINGPOINTLIST
DESCRIPTOR.message_types_by_name['LocationAndPoseMessage'] = _LOCATIONANDPOSEMESSAGE
DESCRIPTOR.message_types_by_name['PoseMessage'] = _POSEMESSAGE
DESCRIPTOR.message_types_by_name['PoseMessageData'] = _POSEMESSAGEDATA
DESCRIPTOR.message_types_by_name['CameraMessage'] = _CAMERAMESSAGE
DESCRIPTOR.message_types_by_name['RobotFileData'] = _ROBOTFILEDATA
DESCRIPTOR.message_types_by_name['RobotFilesUpdateMessage'] = _ROBOTFILESUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['KeyValueCustomElement'] = _KEYVALUECUSTOMELEMENT
DESCRIPTOR.message_types_by_name['KeyValuePairs'] = _KEYVALUEPAIRS
DESCRIPTOR.message_types_by_name['DiagnosticsMessage'] = _DIAGNOSTICSMESSAGE
DESCRIPTOR.message_types_by_name['TextFileMessage'] = _TEXTFILEMESSAGE
DESCRIPTOR.message_types_by_name['CustomDataMessage'] = _CUSTOMDATAMESSAGE
DESCRIPTOR.message_types_by_name['TopicMonitorMessage'] = _TOPICMONITORMESSAGE
DESCRIPTOR.message_types_by_name['ParamMonitorMessage'] = _PARAMMONITORMESSAGE
DESCRIPTOR.message_types_by_name['NodeMonitorMessage'] = _NODEMONITORMESSAGE
DESCRIPTOR.message_types_by_name['ServiceMonitorMessage'] = _SERVICEMONITORMESSAGE
DESCRIPTOR.message_types_by_name['RosMonitorMessage'] = _ROSMONITORMESSAGE
DESCRIPTOR.message_types_by_name['RosOutMessage'] = _ROSOUTMESSAGE
DESCRIPTOR.message_types_by_name['CustomCommandRosMessage'] = _CUSTOMCOMMANDROSMESSAGE
DESCRIPTOR.message_types_by_name['CustomScriptCommandMessage'] = _CUSTOMSCRIPTCOMMANDMESSAGE
DESCRIPTOR.message_types_by_name['CustomScriptStatusMessage'] = _CUSTOMSCRIPTSTATUSMESSAGE
DESCRIPTOR.message_types_by_name['TeleopGoCommand'] = _TELEOPGOCOMMAND
DESCRIPTOR.message_types_by_name['KeyValueMessage'] = _KEYVALUEMESSAGE
DESCRIPTOR.message_types_by_name['RosDiagnosticsField'] = _ROSDIAGNOSTICSFIELD
DESCRIPTOR.message_types_by_name['RosDiagnosticsMessage'] = _ROSDIAGNOSTICSMESSAGE
DESCRIPTOR.message_types_by_name['RosDiagnosticsStatusMessage'] = _ROSDIAGNOSTICSSTATUSMESSAGE
DESCRIPTOR.message_types_by_name['StateOptions'] = _STATEOPTIONS
DESCRIPTOR.message_types_by_name['ModuleStateOptionsMessage'] = _MODULESTATEOPTIONSMESSAGE
DESCRIPTOR.enum_types_by_name['Nav2DWaypointFrame'] = _NAV2DWAYPOINTFRAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiskUsageMessage = _reflection.GeneratedProtocolMessageType('DiskUsageMessage', (_message.Message,), {
  'DESCRIPTOR' : _DISKUSAGEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.DiskUsageMessage)
  })
_sym_db.RegisterMessage(DiskUsageMessage)

NetworkStatsMessage = _reflection.GeneratedProtocolMessageType('NetworkStatsMessage', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKSTATSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.NetworkStatsMessage)
  })
_sym_db.RegisterMessage(NetworkStatsMessage)

SystemStatsMessage = _reflection.GeneratedProtocolMessageType('SystemStatsMessage', (_message.Message,), {
  'DESCRIPTOR' : _SYSTEMSTATSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.SystemStatsMessage)
  })
_sym_db.RegisterMessage(SystemStatsMessage)

OdometryDataMessage = _reflection.GeneratedProtocolMessageType('OdometryDataMessage', (_message.Message,), {
  'DESCRIPTOR' : _ODOMETRYDATAMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.OdometryDataMessage)
  })
_sym_db.RegisterMessage(OdometryDataMessage)

PathPoint = _reflection.GeneratedProtocolMessageType('PathPoint', (_message.Message,), {
  'DESCRIPTOR' : _PATHPOINT,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.PathPoint)
  })
_sym_db.RegisterMessage(PathPoint)

DeltaIntPathPoints = _reflection.GeneratedProtocolMessageType('DeltaIntPathPoints', (_message.Message,), {
  'DESCRIPTOR' : _DELTAINTPATHPOINTS,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.DeltaIntPathPoints)
  })
_sym_db.RegisterMessage(DeltaIntPathPoints)

RobotPath = _reflection.GeneratedProtocolMessageType('RobotPath', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTPATH,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RobotPath)
  })
_sym_db.RegisterMessage(RobotPath)

DeltaIntArray = _reflection.GeneratedProtocolMessageType('DeltaIntArray', (_message.Message,), {

  'StatsEntry' : _reflection.GeneratedProtocolMessageType('StatsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELTAINTARRAY_STATSENTRY,
    '__module__' : 'inorbit_pb2'
    # @@protoc_insertion_point(class_scope:inorbit.DeltaIntArray.StatsEntry)
    })
  ,
  'DESCRIPTOR' : _DELTAINTARRAY,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.DeltaIntArray)
  })
_sym_db.RegisterMessage(DeltaIntArray)
_sym_db.RegisterMessage(DeltaIntArray.StatsEntry)

PathDataMessage = _reflection.GeneratedProtocolMessageType('PathDataMessage', (_message.Message,), {
  'DESCRIPTOR' : _PATHDATAMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.PathDataMessage)
  })
_sym_db.RegisterMessage(PathDataMessage)

MapMessage = _reflection.GeneratedProtocolMessageType('MapMessage', (_message.Message,), {
  'DESCRIPTOR' : _MAPMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.MapMessage)
  })
_sym_db.RegisterMessage(MapMessage)

MapRequest = _reflection.GeneratedProtocolMessageType('MapRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAPREQUEST,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.MapRequest)
  })
_sym_db.RegisterMessage(MapRequest)

Nav2DWaypointMessage = _reflection.GeneratedProtocolMessageType('Nav2DWaypointMessage', (_message.Message,), {
  'DESCRIPTOR' : _NAV2DWAYPOINTMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.Nav2DWaypointMessage)
  })
_sym_db.RegisterMessage(Nav2DWaypointMessage)

Nav2DPathMessage = _reflection.GeneratedProtocolMessageType('Nav2DPathMessage', (_message.Message,), {
  'DESCRIPTOR' : _NAV2DPATHMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.Nav2DPathMessage)
  })
_sym_db.RegisterMessage(Nav2DPathMessage)

AlertMessage = _reflection.GeneratedProtocolMessageType('AlertMessage', (_message.Message,), {
  'DESCRIPTOR' : _ALERTMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.AlertMessage)
  })
_sym_db.RegisterMessage(AlertMessage)

Echo = _reflection.GeneratedProtocolMessageType('Echo', (_message.Message,), {
  'DESCRIPTOR' : _ECHO,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.Echo)
  })
_sym_db.RegisterMessage(Echo)

DatabagUpdateMessage = _reflection.GeneratedProtocolMessageType('DatabagUpdateMessage', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATABAGUPDATEMESSAGE_PROPERTIESENTRY,
    '__module__' : 'inorbit_pb2'
    # @@protoc_insertion_point(class_scope:inorbit.DatabagUpdateMessage.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _DATABAGUPDATEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.DatabagUpdateMessage)
  })
_sym_db.RegisterMessage(DatabagUpdateMessage)
_sym_db.RegisterMessage(DatabagUpdateMessage.PropertiesEntry)

RosbagUpdateMessage = _reflection.GeneratedProtocolMessageType('RosbagUpdateMessage', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ROSBAGUPDATEMESSAGE_PROPERTIESENTRY,
    '__module__' : 'inorbit_pb2'
    # @@protoc_insertion_point(class_scope:inorbit.RosbagUpdateMessage.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _ROSBAGUPDATEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RosbagUpdateMessage)
  })
_sym_db.RegisterMessage(RosbagUpdateMessage)
_sym_db.RegisterMessage(RosbagUpdateMessage.PropertiesEntry)

LaserMessage = _reflection.GeneratedProtocolMessageType('LaserMessage', (_message.Message,), {
  'DESCRIPTOR' : _LASERMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.LaserMessage)
  })
_sym_db.RegisterMessage(LaserMessage)

FloatingPointList = _reflection.GeneratedProtocolMessageType('FloatingPointList', (_message.Message,), {
  'DESCRIPTOR' : _FLOATINGPOINTLIST,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.FloatingPointList)
  })
_sym_db.RegisterMessage(FloatingPointList)

LocationAndPoseMessage = _reflection.GeneratedProtocolMessageType('LocationAndPoseMessage', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONANDPOSEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.LocationAndPoseMessage)
  })
_sym_db.RegisterMessage(LocationAndPoseMessage)

PoseMessage = _reflection.GeneratedProtocolMessageType('PoseMessage', (_message.Message,), {
  'DESCRIPTOR' : _POSEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.PoseMessage)
  })
_sym_db.RegisterMessage(PoseMessage)

PoseMessageData = _reflection.GeneratedProtocolMessageType('PoseMessageData', (_message.Message,), {
  'DESCRIPTOR' : _POSEMESSAGEDATA,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.PoseMessageData)
  })
_sym_db.RegisterMessage(PoseMessageData)

CameraMessage = _reflection.GeneratedProtocolMessageType('CameraMessage', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.CameraMessage)
  })
_sym_db.RegisterMessage(CameraMessage)

RobotFileData = _reflection.GeneratedProtocolMessageType('RobotFileData', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTFILEDATA,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RobotFileData)
  })
_sym_db.RegisterMessage(RobotFileData)

RobotFilesUpdateMessage = _reflection.GeneratedProtocolMessageType('RobotFilesUpdateMessage', (_message.Message,), {
  'DESCRIPTOR' : _ROBOTFILESUPDATEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RobotFilesUpdateMessage)
  })
_sym_db.RegisterMessage(RobotFilesUpdateMessage)

KeyValueCustomElement = _reflection.GeneratedProtocolMessageType('KeyValueCustomElement', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUECUSTOMELEMENT,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.KeyValueCustomElement)
  })
_sym_db.RegisterMessage(KeyValueCustomElement)

KeyValuePairs = _reflection.GeneratedProtocolMessageType('KeyValuePairs', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEPAIRS,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.KeyValuePairs)
  })
_sym_db.RegisterMessage(KeyValuePairs)

DiagnosticsMessage = _reflection.GeneratedProtocolMessageType('DiagnosticsMessage', (_message.Message,), {
  'DESCRIPTOR' : _DIAGNOSTICSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.DiagnosticsMessage)
  })
_sym_db.RegisterMessage(DiagnosticsMessage)

TextFileMessage = _reflection.GeneratedProtocolMessageType('TextFileMessage', (_message.Message,), {
  'DESCRIPTOR' : _TEXTFILEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.TextFileMessage)
  })
_sym_db.RegisterMessage(TextFileMessage)

CustomDataMessage = _reflection.GeneratedProtocolMessageType('CustomDataMessage', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMDATAMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.CustomDataMessage)
  })
_sym_db.RegisterMessage(CustomDataMessage)

TopicMonitorMessage = _reflection.GeneratedProtocolMessageType('TopicMonitorMessage', (_message.Message,), {
  'DESCRIPTOR' : _TOPICMONITORMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.TopicMonitorMessage)
  })
_sym_db.RegisterMessage(TopicMonitorMessage)

ParamMonitorMessage = _reflection.GeneratedProtocolMessageType('ParamMonitorMessage', (_message.Message,), {
  'DESCRIPTOR' : _PARAMMONITORMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.ParamMonitorMessage)
  })
_sym_db.RegisterMessage(ParamMonitorMessage)

NodeMonitorMessage = _reflection.GeneratedProtocolMessageType('NodeMonitorMessage', (_message.Message,), {
  'DESCRIPTOR' : _NODEMONITORMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.NodeMonitorMessage)
  })
_sym_db.RegisterMessage(NodeMonitorMessage)

ServiceMonitorMessage = _reflection.GeneratedProtocolMessageType('ServiceMonitorMessage', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEMONITORMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.ServiceMonitorMessage)
  })
_sym_db.RegisterMessage(ServiceMonitorMessage)

RosMonitorMessage = _reflection.GeneratedProtocolMessageType('RosMonitorMessage', (_message.Message,), {
  'DESCRIPTOR' : _ROSMONITORMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RosMonitorMessage)
  })
_sym_db.RegisterMessage(RosMonitorMessage)

RosOutMessage = _reflection.GeneratedProtocolMessageType('RosOutMessage', (_message.Message,), {
  'DESCRIPTOR' : _ROSOUTMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RosOutMessage)
  })
_sym_db.RegisterMessage(RosOutMessage)

CustomCommandRosMessage = _reflection.GeneratedProtocolMessageType('CustomCommandRosMessage', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMCOMMANDROSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.CustomCommandRosMessage)
  })
_sym_db.RegisterMessage(CustomCommandRosMessage)

CustomScriptCommandMessage = _reflection.GeneratedProtocolMessageType('CustomScriptCommandMessage', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMSCRIPTCOMMANDMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.CustomScriptCommandMessage)
  })
_sym_db.RegisterMessage(CustomScriptCommandMessage)

CustomScriptStatusMessage = _reflection.GeneratedProtocolMessageType('CustomScriptStatusMessage', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMSCRIPTSTATUSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.CustomScriptStatusMessage)
  })
_sym_db.RegisterMessage(CustomScriptStatusMessage)

TeleopGoCommand = _reflection.GeneratedProtocolMessageType('TeleopGoCommand', (_message.Message,), {
  'DESCRIPTOR' : _TELEOPGOCOMMAND,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.TeleopGoCommand)
  })
_sym_db.RegisterMessage(TeleopGoCommand)

KeyValueMessage = _reflection.GeneratedProtocolMessageType('KeyValueMessage', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.KeyValueMessage)
  })
_sym_db.RegisterMessage(KeyValueMessage)

RosDiagnosticsField = _reflection.GeneratedProtocolMessageType('RosDiagnosticsField', (_message.Message,), {
  'DESCRIPTOR' : _ROSDIAGNOSTICSFIELD,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RosDiagnosticsField)
  })
_sym_db.RegisterMessage(RosDiagnosticsField)

RosDiagnosticsMessage = _reflection.GeneratedProtocolMessageType('RosDiagnosticsMessage', (_message.Message,), {
  'DESCRIPTOR' : _ROSDIAGNOSTICSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RosDiagnosticsMessage)
  })
_sym_db.RegisterMessage(RosDiagnosticsMessage)

RosDiagnosticsStatusMessage = _reflection.GeneratedProtocolMessageType('RosDiagnosticsStatusMessage', (_message.Message,), {
  'DESCRIPTOR' : _ROSDIAGNOSTICSSTATUSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.RosDiagnosticsStatusMessage)
  })
_sym_db.RegisterMessage(RosDiagnosticsStatusMessage)

StateOptions = _reflection.GeneratedProtocolMessageType('StateOptions', (_message.Message,), {
  'DESCRIPTOR' : _STATEOPTIONS,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.StateOptions)
  })
_sym_db.RegisterMessage(StateOptions)

ModuleStateOptionsMessage = _reflection.GeneratedProtocolMessageType('ModuleStateOptionsMessage', (_message.Message,), {
  'DESCRIPTOR' : _MODULESTATEOPTIONSMESSAGE,
  '__module__' : 'inorbit_pb2'
  # @@protoc_insertion_point(class_scope:inorbit.ModuleStateOptionsMessage)
  })
_sym_db.RegisterMessage(ModuleStateOptionsMessage)


_DELTAINTARRAY_STATSENTRY._options = None
_DATABAGUPDATEMESSAGE_PROPERTIESENTRY._options = None
_ROSBAGUPDATEMESSAGE_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)
